import { ApolloError } from "apollo-server-micro";
import { callMedicalDb, crushableSpecialtiesBody } from "../queryMedicalDb";
import { getCrushableWithoutBackslashes } from "../toolbox/crushabilityTools";
import {
  DTOCrushableSpecialtiesResponse,
  FormDoseAndCrushableSpecialties,
} from "../types";

export const getCrushableSpecialties = async ({
  shortname,
}: {
  shortname: string;
}): Promise<FormDoseAndCrushableSpecialties[]> => {
  const { drugs } = (await callMedicalDb(crushableSpecialtiesBody, {
    shortname,
  })) as unknown as DTOCrushableSpecialtiesResponse;

  if (drugs.length === 0) {
    throw new ApolloError(`Error: There is no drug with this shortname.`);
  }

  return drugs
    .map(({ form, dose, specialties }) => {
      return {
        form,
        dose,
        crushableSpecialties: specialties
          .filter(({ crushable }) => crushable?.recommandations !== null)
          .map(({ name, crushable }) => {
            return {
              name,
              crushable: getCrushableWithoutBackslashes(crushable),
            };
          }),
      };
    })
    .filter(({ crushableSpecialties }) => crushableSpecialties.length > 0);
};
